/*
 * @Descripttion: This is an LaTeX template for NJU EE undergraduate exam
 * @version: 1.0.2
 * @Author: Ethan Lyu
 * @Date: 2022-06-29 14:41:07
 * @LastEditors: Ethan Lyu
 * @LastEditTime: 2022-06-30 23:06:22
 */

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{njuEEexam}[2022/06/24 NJU EE exam template]

\LoadClass{exam}
\RequirePackage{amsmath,amssymb,amsthm}	%美国数学学会系列
\RequirePackage{mathtools}	%amsmath增强包
\RequirePackage{tikz}	%tikz用于画图包
\RequirePackage{xeCJK,zhnumber} %支持中文，中文数字包
\RequirePackage{geometry}	%设置页边距等
\RequirePackage{graphicx} 		% 插入图片
\RequirePackage{hyperref} 		% 插入链接
\RequirePackage{booktabs} 		% 表格样式
\RequirePackage{fontspec}
\RequirePackage{multicol}
\RequirePackage{xifthen}
\RequirePackage{array}

% 设置字体，仅在Windows和NJU Tex运行，其他平台请参考网上对应教程
\setCJKmainfont{SimSun}[AutoFakeBold]
\setmainfont{Times New Roman}
\setCJKfamilyfont{hei}{SimHei}    %黑体  hei  
\newcommand{\heiti}{\CJKfamily{hei}}  

% 定义默认字体大小和行距
\renewcommand{\normalsize}{\fontsize{12pt}{\baselineskip}\selectfont}
% 其它比较常见的字体字号设置
\newcommand{\chuhao}{\fontsize{42pt}{\baselineskip}\selectfont}
\newcommand{\xiaochuhao}{\fontsize{36pt}{\baselineskip}\selectfont}
\newcommand{\yihao}{\fontsize{28pt}{\baselineskip}\selectfont}
\newcommand{\erhao}{\fontsize{21pt}{\baselineskip}\selectfont}
\newcommand{\xiaoerhao}{\fontsize{18pt}{\baselineskip}\selectfont}
\newcommand{\sanhao}{\fontsize{15.75pt}{\baselineskip}\selectfont}
\newcommand{\sihao}{\fontsize{14pt}{\baselineskip}\selectfont}
\newcommand{\xiaosihao}{\fontsize{12pt}{\baselineskip}\selectfont}
\newcommand{\wuhao}{\fontsize{10.5pt}{\baselineskip}\selectfont}
\newcommand{\xiaowuhao}{\fontsize{9pt}{\baselineskip}\selectfont}
\newcommand{\liuhao}{\fontsize{7.875pt}{\baselineskip}\selectfont}
\newcommand{\qihao}{\fontsize{5.25pt}{\baselineskip}\selectfont}
% 设置边距
\geometry{margin=1in}

\pointname{ 分}
\pointformat{(\thepoints)}

\newcommand{\tf}[1][{}]{%
\fillin[#1][0.25in]%
}

% \hypersetup{hidelinks}

% 更改成中文样式的题号
\renewcommand{\thequestion}{\zhnum{question}}
\renewcommand{\questionlabel}{\thequestion 、}
\renewcommand{\thepartno}{\arabic{partno}}
\renewcommand{\partlabel}{\thepartno .}
\renewcommand{\thesubpart}{}
\renewcommand{\subpartlabel}{(\thesubpart .)}
\renewcommand{\thesubsubpart}{}
\renewcommand{\subsubpartlabel}{\thesubsubpart .}
% \renewcommand{\thechoice}

\renewcommand{\choiceshook}{%
    \setlength{\leftmargin}{15pt}%
    \setlength{\labelwidth}{-\labelsep}%
}

% 考试科目
\newcommand{\@examclass}{}
\newcommand{\examclass}[1]{\renewcommand{\@examclass}{#1}}

% 期中/期末
\newcommand{\@examnum}{}
\newcommand{\examnum}[1]{\renewcommand{\@examnum}{#1}}

% 开卷/闭卷
\newcommand{\@examtype}{}
\newcommand{\examtype}[1]{\renewcommand{\@examtype}{#1}}
% {
%     \ifthenelse{\isempty{#1}}
%     {开卷}
%     {#1}
% }

% 考试日期
\newcommand{\@examdate}{}
\newcommand{\examdate}[1]{\renewcommand{\@examdate}{#1}}

% 考试时长
\newcommand{\@examlen}{}
\newcommand{\examlen}[1]{\renewcommand{\@examlen}{#1}}

% 学期
\newcommand{\@examterm}{}
\newcommand{\examterm}[1]{\renewcommand{\@examterm}{#1}}

% 学期
\newcommand{\@examyear}{}
\newcommand{\examyear}[1]{\renewcommand{\@examyear}{#1}}

% A/B/C卷
\newcommand{\@examAB}{}
\newcommand{\examAB}[1]{\renewcommand{\@examAB}{#1}}

%设置页眉页脚
\pagestyle{headandfoot}
\firstpageheadrule
\firstpageheader{}{\@examAB 卷}{\@examterm 学年第 \underline{\@examyear} 学期}
\runningheader{}{\@examAB 卷}{\@examterm 学年第 \underline{\@examyear} 学期}
\runningheadrule
\firstpagefooter{}{第\thepage\ 页（共\numpages 页）}{}
\runningfooter{}{第\thepage\ 页（共\numpages 页）}{}

\renewcommand{\maketitle}{
    \begin{center}
        \Large \textbf{南京大学 \quad 电子科学与工程学院 \quad 全日制统招本科生}\\
        \Large \textbf{\underline{\@examclass} \@examnum 考试试卷} \qquad \textbf{\@examtype}\\
        {\Large \textbf{考试日期： \underline{\@examdate} \qquad 考试时长：\underline{\@examlen}小时}}\\
        {\small 考生年级：\fillin[][1cm] \quad 考生专业：\fillin \quad 考生学号：\fillin[][2cm] \quad 考生姓名：\fillin}
    \end{center}
}

\newcommand{\makegradetable}{
    \begin{center}
        % Grade Table
        \htword{\textbf{总分}}
        \hqword{题号} 
        \hpword{分数}
        \hsword{得分}
        \addpoints
        \cellwidth{3em}
        \gradetable[h][questions]
    \end{center}
}



% \def\bf#1{\textbf{#1}}
\newcommand{\hquestion}[2][10]{{\Large \heiti \question[#1]{#2}}}
% \newcommand{\bquestion}[2][30]{{\Large \question[#1]{#2}}}
\renewcommand\questionshook{\large}
% \renewcommand\partshook{\normalsize\normalfont}

% \newcommand{\question}[2][]{%
%     \ifthenelse{\isempty{#1}}{%
%         \question \textbf{#2}%
%     }{%
%         % \renewcommand{\thequestion}{\bfseries\zhnum{question}}
%         \qformat{\textbf{\questionlabel (本题共\thepoints){#2} }\hfill}
%         \question[#1] %
%         \noqformat
%     }%
% }
\newcommand{\questionTable}{%
% 五号宋体加粗
    \begin{tabular}{|c|p{1.5cm}<{\centering}|}\hline
    本题得分 &   \\
    \hline
    \end{tabular}
%   \gdef\questionTable{}%
}
\newcommand{\bquestion}[2][10]{{\large\bfseries\question[#1]{#2}}\hfill\questionTable}

% \renewcommand{\question}[2]{
%     \qformat{\questionlabel (本题共\thepoints){#2} \hfill}
%     \question[#1]
%     \noqformat
% }




